
# Class: AnyType




URI: [nwb_schema_language:AnyType](https://w3id.org/p2p_ld/nwb-schema-language/AnyType)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Attribute]++-%20default_value%200..1>[AnyType],[Dataset]++-%20default_value%200..1>[AnyType],[Attribute]++-%20value%200..1>[AnyType],[Dataset]++-%20value%200..1>[AnyType],[Dataset],[Attribute])](https://yuml.me/diagram/nofunky;dir:TB/class/[Attribute]++-%20default_value%200..1>[AnyType],[Dataset]++-%20default_value%200..1>[AnyType],[Attribute]++-%20value%200..1>[AnyType],[Dataset]++-%20value%200..1>[AnyType],[Dataset],[Attribute])

## Referenced by Class

 *  **None** *[default_value](default_value.md)*  <sub>0..1</sub>  **[AnyType](AnyType.md)**
 *  **None** *[value](value.md)*  <sub>0..1</sub>  **[AnyType](AnyType.md)**

## Attributes


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | linkml:Any |

